Improve this doc View Source

The $sceProvider provider allows developers to configure the $sce service.

- enable/disable Strict Contextual Escaping (SCE) in a module
- override the default implementation with a custom delegate

Read more about Strict Contextual Escaping (SCE).

## Methods

- ###

  `enabled([value]);`

  Enables/disables SCE and returns the current value.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  value (optional) | boolean | If provided, then enables/disables SCE.

  #### Returns

  boolean | true if SCE is enabled, false otherwise.